@@ -516,6 +516,8 @@ class SearchDialog(QDialog, Ui_searchDialog):
         searchOrder = searchDict.get(unicode(self.searchOrderButton.valueText()))
         if searchString in SearchDialog.recentSearches:
             SearchDialog.recentSearches.removeAll(searchString)
+        if SearchDialog.recentSearches.count() > 30:
+            SearchDialog.removeAt(30)
         SearchDialog.recentSearches.prepend(searchString)
         searchWindow = cutetubewindows.SearchResultsWindow(self, searchString, searchOrder, self.username)
         
