@@ -42,6 +42,7 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
         self.keyPressEvent = self.showSearchDialog
         for button in (self.myAccountButton, self.mostRecentButton, self.mostViewedButton, self.searchButton):
             button.setStyleSheet("border: 2px solid rgb(120, 120, 120); border-radius: 6px;") 
+        self.searchDialogRaised = False
         taskQueueLength = len(youtubeservice.YouTubeVideoDownloader.taskQueue)
         if taskQueueLength > 0:
             self.actionDownloads.setVisible(True)
@@ -76,11 +77,16 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
         """
         Raises a SearchDialog when the user presses a key.
         """
-        if event.key() not in (Qt.Key_Left, Qt.Key_Right, Qt.Key_Up, Qt.Key_Down, Qt.Key_Backspace, Qt.Key_Return, Qt.Key_Control, Qt.Key_Shift, Qt.Key_Space):
+        if event.key() not in (Qt.Key_Left, Qt.Key_Right, Qt.Key_Up, Qt.Key_Down, Qt.Key_Backspace, Qt.Key_Return, Qt.Key_Control, Qt.Key_Shift, Qt.Key_Space) and not self.searchDialogRaised:
+            self.setSearchDialogRaised(True)
             searchDialog = cutetubedialogs.SearchDialog(self)
             searchDialog.lineEdit.insert(event.text())
+            QTimer.singleShot(1000,  lambda isRaised = False: self.setSearchDialogRaised(isRaised))
         else:
             pass
+            
+    def setSearchDialogRaised(self,  isRaised):
+        self.searchDialogRaised = isRaised
                 
     def restoreSettings(self):
         """
